tlslite.messages.HandshakeMsg

Package tlslite :: Module messages :: Class HandshakeMsg |
[show private | hide private]
[frames | no frames]

## Class HandshakeMsg

    Msg --+
          |
         HandshakeMsg

Known Subclasses:
  `Certificate`, `CertificateRequest`, `CertificateVerify`, `ClientHello`, `ClientKeyExchange`, `Finished`, `ServerHello`, `ServerHelloDone`, `ServerKeyExchange`

Method Summary
| `preWrite(self, handshakeType, trial)`
Inherited from Msg
| ``postWrite`(self, w, trial)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:56 2005 | http://epydoc.sf.net